@@ -1,9 +1,9 @@
 package Devel::REPL::Error;
-BEGIN {
-  $Devel::REPL::Error::AUTHORITY = 'cpan:PHAYLON';
-}
-$Devel::REPL::Error::VERSION = '1.003026';
+
+our $VERSION = '1.003028';
+
 use Moose;
+use namespace::autoclean;
 
 # FIXME get nothingmuch to refactor and release his useful error object
 
@@ -25,5 +25,3 @@ sub stringify {
   sprintf "%s: %s", $self->type, $self->message;
 }
 __PACKAGE__
-
-__END__
