@@ -1,12 +1,12 @@
 use strict;
 use warnings;
 package Devel::REPL::Plugin;
-BEGIN {
-  $Devel::REPL::Plugin::AUTHORITY = 'cpan:PHAYLON';
-}
-$Devel::REPL::Plugin::VERSION = '1.003026';
+
+our $VERSION = '1.003028';
+
 use Devel::REPL::Meta::Plugin;
 use Moose::Role ();
+use namespace::autoclean;
 
 sub import {
   my $target = caller;
