@@ -3,7 +3,7 @@ use warnings;
 package Devel::REPL::Plugin::Colors;
 # ABSTRACT: Add color to return values, warnings, and errors
 
-our $VERSION = '1.003027';
+our $VERSION = '1.003028';
 
 use Devel::REPL::Plugin;
 use Term::ANSIColor;
@@ -76,7 +76,7 @@ Devel::REPL::Plugin::Colors - Add color to return values, warnings, and errors
 
 =head1 VERSION
 
-version 1.003027
+version 1.003028
 
 =head1 SYNOPSIS
 
@@ -103,6 +103,14 @@ defaults are actually 'green' and 'bold red'.
 
 C<Devel::REPL>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
+
 =head1 AUTHOR
 
 Shawn M Moore, C<< <sartak at gmail dot com> >>
