@@ -3,7 +3,7 @@ use warnings;
 package Devel::REPL::Plugin::FancyPrompt;
 # ABSTRACT: Facilitate user-defined prompts
 
-our $VERSION = '1.003027';
+our $VERSION = '1.003028';
 
 use Devel::REPL::Plugin;
 use namespace::autoclean;
@@ -72,7 +72,7 @@ Devel::REPL::Plugin::FancyPrompt - Facilitate user-defined prompts
 
 =head1 VERSION
 
-version 1.003027
+version 1.003028
 
 =head1 SYNOPSIS
 
@@ -116,6 +116,14 @@ C<fancy_prompt>'s default (except C<*> instead of C<< > >>).
 
 C<Devel::REPL>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-REPL>
+(or L<bug-Devel-REPL@rt.cpan.org|mailto:bug-Devel-REPL@rt.cpan.org>).
+
+There is also an irc channel available for users of this distribution, at
+L<C<#devel> on C<irc.perl.org>|irc://irc.perl.org/#devel-repl>.
+
 =head1 AUTHOR
 
 Shawn M Moore, C<< <sartak at gmail dot com> >>
